import axios from 'axios'
import {Loading, Message} from 'element-ui'
import { Notification } from 'element-ui'
import { getToken } from '@/utils/auth'
import Config from '@/settings'

let downloadLoadingInstance;
// 使请求头可以携带cookie
axios.defaults.withCredentials = true;

//var baseURL = (VUE_APP_API.ServiceURL || process.env.VUE_APP_LOCAL_API) + '/';
var baseURL = process.env.NODE_ENV
 === 'development' ? process.env.VUE_APP_LOCAL_API + '/' : (VUE_APP_API.ServiceURL || process.env.VUE_APP_LOCAL_API) + '/';

// 创建axios实例
const service = axios.create({
	baseURL: baseURL,
	timeout: Config.timeout // 请求超时时间
})

// request拦截器
service.interceptors.request.use(
  config => {
    if (getToken()) {
      config.headers['Authorization'] = getToken() // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    config.headers['Content-Type'] = 'application/json'
    return config
  },
  error => {
    Promise.reject(error)
  }
)

// response 拦截器
service.interceptors.response.use(
  response => {
    return response.data
  },
  error => {
    if (error.response.status) {
      const responseCode = error.response.status

      switch (responseCode) {
        case 400:
          // Message.error('操作失败');

          break

          //  token 过期
        case 401:
			Notification({
				title: '登录过期，请重新登录',
				duration: 2000,
				type: 'warning'
			})

			setTimeout(() => {
				window.localStorage.removeItem('token')
				window.location = '#/';
				location.reload()
			}, 1000)

			break

        default:
          break
      }
      return error.response.data
    }
  }
)

// 通用下载方法
export function download(url, params, filename, config) {
  console.log(url, params, filename, config,'url, params, filename, config')
  downloadLoadingInstance = Loading.service({ text: "正在下载数据，请稍候", spinner: "el-icon-loading", background: "rgba(0, 0, 0, 0.7)", })
  return service.post(url, params, {
    transformRequest: [(params) => { return tansParams(params) }],
    headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
    responseType: 'blob',
    ...config
  }).then(async (data) => {
    const isBlob = blobValidate(data);
    if (isBlob) {
      const blob = new Blob([data])
      saveAs(blob, filename)
    } else {
      const resText = await data.text();
      const rspObj = JSON.parse(resText);
      const errMsg = errorCode[rspObj.code] || rspObj.msg || errorCode['default']
      Message.error(errMsg);
    }
    downloadLoadingInstance.close();
  }).catch((r) => {
    console.error(r)
    Message.error('下载文件出现错误，请联系管理员！')
    downloadLoadingInstance.close();
  })
}
export default service
